=================
How to contribute
=================

🎉👍 First things first, thank you for considering contributing to *smif*!

Getting started
---------------

Please `raise an issue`_ if you find a bug or would like to propose a feature.

Github `pull requests`_ are welcome, but please discuss the change in an issue before opening
a pull request.

Use cases and broader pieces of design are discussed in the `wiki`_.

References
----------

See the `developer documentation`_ for details of testing and other conventions.

See the project `code of conduct`_ to be aware of our expectations of an open and welcoming
environment.

.. _developer documentation: http://smif.readthedocs.io/en/latest/developers.html
.. _pull requests: https://help.github.com/articles/about-pull-requests/
.. _raise an issue: https://github.com/nismod/smif/issues
.. _wiki: https://github.com/nismod/smif/wiki
.. _code of conduct: https://github.com/nismod/smif/blob/master/CODE_OF_CONDUCT.md
